@@ -16,6 +16,6 @@
 #' @export
 pop_hwd <- function(ped, reference = NULL) {
   check_basic(ped, "id", "dam", "sire")
-  if (!base::is.null(reference)) reference <- check_reference(ped, reference, "reference")
+  if (!base::is.null(reference)) reference <- check_reference(ped, reference)
   .Call(`_purgeR_hwd`, ped, reference)
 }
\ No newline at end of file
